@@ -4,10 +4,8 @@ import os
 import json
 import time
 import requests
-import requests_gssapi
 from copr.v3.helpers import List
 from munch import Munch
-from future.utils import raise_from
 from requests_toolbelt.multipart.encoder import MultipartEncoder, MultipartEncoderMonitor
 from .exceptions import CoprRequestException, CoprNoResultException, CoprTimeoutException, CoprAuthException
 
@@ -56,16 +54,16 @@ class Request(object):
         for i in range(1, self.connection_attempts + 1):
             try:
                 response = requests.request(**request_params)
-            except requests_gssapi.exceptions.SPNEGOExchangeError as e:
-                raise_from(CoprAuthException("GSSAPI authentication failed."), e)
+                if response.status_code == 401 and i < self.connection_attempts:
+                    # try to authenticate again, don't sleep!
+                    self._update_auth_params(request_params, auth, reauth=True)
+                    continue
+                # Return the response object (even for non-200 status codes!)
+                return response
             except requests.exceptions.ConnectionError:
                 if i < self.connection_attempts:
                     time.sleep(sleep)
-            else:
-                if response.status_code == 401:
-                    self._update_auth_params(request_params, auth, reauth=True)
-                    continue
-                return response
+
         raise CoprRequestException("Unable to connect to {0}.".format(self.api_base_url))
 
     def _request_params(self, endpoint, method=GET, data=None, params=None,
